% P7Ctsim1.m create figures for blog post 7
% REA 2011-06-14->2011-07-05


%% make an image and projections from the spec using Matlab phantom function and radon
nside = 512;
P = phantom('Shepp-Logan',nside); 
   % add '1' inside the phantom for 'air' type phantom
idx = find(abs(P)<eps);
P = P + 1;
P(idx) = 0;   
nangles = 360;
angles = linspace(0,180,nangles+1);
angles = angles(1:(end-1));
pjradon = radon(P,angles);


%% display the image and projections
fh = figure;
subplot(121)
imshow(P,[0.9 1.2]);
subplot(122)
imshow(pjradon,[]);

%% reconstruct using iradon
img_iradon = iradon(pjradon,angles); 

%% display reconstructed image and plot data on line through small ellipses
[ny,nx] = size(img_iradon);
ny4line = round(0.8092*ny);
linewid = 1.5;
fh = figure;
   % show image and line for data
subplot(121)
imshow(img_iradon,[0.9 1.2]);
hold on
plot([0 nx],ny4line*[1 1],'-r','linewidth',2*linewid);
hold off
   % show plot of data
subplot(122)
plot(img_iradon(ny4line,:),'-k','linewidth',linewid);
axis([0 nx 0.9 1.1])
hold on
plot([0 nx],[1.03 1.03],':r','linewidth',1.5)
plot([0 nx],[1.02 1.02],':r','linewidth',1.5)
hold off
set(gca,'fontsize',12,'linewidth',1.5)

%% export the figure as png and eps
dirname = 'E:\Projects\Blog\Posts\P7ctsim1\'; % edit this for your computer
figno = sprintf('-f%d',fh);
print(figno,[dirname 'SL_img_radon.png'],'-dpng','-cmyk','-r75') % resolution 100 dpi
   % export as eps
print(figno,[dirname 'SL_img_radon.eps'],'-deps','-cmyk') 

%% make projections using my function
  % Shepp-Logan spec from Kak and Slaney. This is for phantom in air
  % fields are [xcenter, ycenter, A, B, angle(degrees), value]
% SLspec = [ ...
% 0,0,0.92,0.69,90,2;  ...
% 0,-0.0184,0.874,0.6624,90,-0.98;  ...
% 0.22,0,0.31,0.11,72,-0.02;  ...
% -0.22,0,0.41,0.16,108,-0.02;  ...
% 0,0.35,0.25,0.21,90,0.01;  ...
% 0,0.1,0.046,0.046,0,0.01;  ...
% 0,-0.1,0.046,0.046,0,0.01;  ...
% -0.08,-0.605,0.046,0.023,0,0.01;  ...
% 0,-0.605,0.023,0.023,0,0.01;  ...
% 0.06,-0.605,0.046,0.023,90,0.01;  ...
% ];
% 
% spec = [nside*SLspec(:,1:4) SLspec(:,5:6)]; 
% pixel_size = 2;
% [prj,zsiz] = ct_proj_parallel(pixel_size,nangles,'ellipse',spec);
% pj_ctproj = reshape(prj,zcomp(zsiz));

%% If you do not have ct_proj_parallel, load the projection data
load('E:\Projects\Blog\Posts\P7ctsim1\SLprj.mat'); % edit file path for your system

%% reconstruct image
img_ctrecon = CTrecon(pj_ctproj,'angles',angles); 

%% reconstruct my data using iradon
img_iradon2 = iradon(pj_ctproj,angles);

%% display image and plot data
[ny,nx] = size(img_ctrecon);
ny4line = round(0.8092*ny);
linewid = 1.5;
fh = figure;

   % show image and line for my data
subplot(131)
imshow(img_ctrecon,[0.9 1.2]);
hold on
plot([0 nx],ny4line*[1 1],'-r','linewidth',2*linewid);
hold off

   % show plot of image data
subplot(132)
plot(img_ctrecon(ny4line,:),'-k','linewidth',linewid);
axis([0 nx 0.9 1.1])
hold on
plot([0 nx],[1.03 1.03],':r','linewidth',1.5)
plot([0 nx],[1.02 1.02],':r','linewidth',1.5)
hold off
set(gca,'fontsize',12,'linewidth',1.5)
title('CTrecon')

   % show reconstruct of my data with iradon
subplot(133)   
plot(img_iradon2(ny4line,:),'-k','linewidth',linewid);
axis([0 nx 0.9 1.1])
hold on
plot([0 nx],[1.03 1.03],':r','linewidth',1.5)
plot([0 nx],[1.02 1.02],':r','linewidth',1.5)
hold off
set(gca,'fontsize',12,'linewidth',1.5)
title('iradon')

%% export the figure as png and eps
dirname = 'E:\Projects\Blog\Posts\P7ctsim1\'; % edit this for your computer
fname = 'SL_img_ct_proj_parallel';
figno = sprintf('-f%d',fh);
print(figno,[dirname fname '.png'],'-dpng','-cmyk','-r75') % resolution 100 dpi
   % export as eps
print(figno,[dirname fname '.eps'],'-deps','-cmyk') 
